==> pystan-2.4.0.2.tar.gz: pystan-2.4.0.2/pystan/stan/src/stan/agrad/rev/functions.hpp <==
#ifndef __STAN__AGRAD__REV__FUNCTIONS_HPP__
#define __STAN__AGRAD__REV__FUNCTIONS_HPP__

#include <stan/agrad/rev/functions/Phi.hpp>
#include <stan/agrad/rev/functions/Phi_approx.hpp>
#include <stan/agrad/rev/functions/abs.hpp>
#include <stan/agrad/rev/functions/acos.hpp>
#include <stan/agrad/rev/functions/acosh.hpp>
#include <stan/agrad/rev/functions/as_bool.hpp>
#include <stan/agrad/rev/functions/asin.hpp>
#include <stan/agrad/rev/functions/asinh.hpp>
#include <stan/agrad/rev/functions/atan.hpp>
#include <stan/agrad/rev/functions/atan2.hpp>
#include <stan/agrad/rev/functions/atanh.hpp>
#include <stan/agrad/rev/functions/bessel_first_kind.hpp>
#include <stan/agrad/rev/functions/bessel_second_kind.hpp>
#include <stan/agrad/rev/functions/binary_log_loss.hpp>
#include <stan/agrad/rev/functions/cbrt.hpp>
#include <stan/agrad/rev/functions/ceil.hpp>
#include <stan/agrad/rev/functions/cos.hpp>
#include <stan/agrad/rev/functions/cosh.hpp>
#include <stan/agrad/rev/functions/digamma.hpp>
#include <stan/agrad/rev/functions/erf.hpp>
#include <stan/agrad/rev/functions/erfc.hpp>
#include <stan/agrad/rev/functions/exp.hpp>
#include <stan/agrad/rev/functions/exp2.hpp>
#include <stan/agrad/rev/functions/expm1.hpp>
#include <stan/agrad/rev/functions/fabs.hpp>
#include <stan/agrad/rev/functions/falling_factorial.hpp>
#include <stan/agrad/rev/functions/fdim.hpp>
#include <stan/agrad/rev/functions/floor.hpp>
#include <stan/agrad/rev/functions/fma.hpp>
#include <stan/agrad/rev/functions/fmax.hpp>
#include <stan/agrad/rev/functions/fmin.hpp>
#include <stan/agrad/rev/functions/fmod.hpp>
#include <stan/agrad/rev/functions/gamma_p.hpp>
#include <stan/agrad/rev/functions/gamma_q.hpp>
#include <stan/agrad/rev/functions/hypot.hpp>
#include <stan/agrad/rev/functions/ibeta.hpp>
#include <stan/agrad/rev/functions/if_else.hpp>
#include <stan/agrad/rev/functions/inv.hpp>
#include <stan/agrad/rev/functions/inv_cloglog.hpp>
#include <stan/agrad/rev/functions/inv_logit.hpp>
#include <stan/agrad/rev/functions/inv_sqrt.hpp>
#include <stan/agrad/rev/functions/inv_square.hpp>
#include <stan/agrad/rev/functions/is_uninitialized.hpp>
#include <stan/agrad/rev/functions/lgamma.hpp>
#include <stan/agrad/rev/functions/lmgamma.hpp>
#include <stan/agrad/rev/functions/log.hpp>
#include <stan/agrad/rev/functions/log10.hpp>
#include <stan/agrad/rev/functions/log1m.hpp>
#include <stan/agrad/rev/functions/log1m_exp.hpp>
#include <stan/agrad/rev/functions/log1p.hpp>
#include <stan/agrad/rev/functions/log1p_exp.hpp>
#include <stan/agrad/rev/functions/log2.hpp>
#include <stan/agrad/rev/functions/log_diff_exp.hpp>
#include <stan/agrad/rev/functions/log_falling_factorial.hpp>
#include <stan/agrad/rev/functions/log_rising_factorial.hpp>
#include <stan/agrad/rev/functions/log_sum_exp.hpp>
#include <stan/agrad/rev/functions/modified_bessel_first_kind.hpp>
#include <stan/agrad/rev/functions/modified_bessel_second_kind.hpp>
#include <stan/agrad/rev/functions/multiply_log.hpp>
#include <stan/agrad/rev/functions/owens_t.hpp>
#include <stan/agrad/rev/functions/pow.hpp>
#include <stan/agrad/rev/functions/rising_factorial.hpp>
#include <stan/agrad/rev/functions/round.hpp>
#include <stan/agrad/rev/functions/sin.hpp>
#include <stan/agrad/rev/functions/sinh.hpp>
#include <stan/agrad/rev/functions/sqrt.hpp>
#include <stan/agrad/rev/functions/square.hpp>
#include <stan/agrad/rev/functions/step.hpp>
#include <stan/agrad/rev/functions/tan.hpp>
#include <stan/agrad/rev/functions/tanh.hpp>
#include <stan/agrad/rev/functions/tgamma.hpp>
#include <stan/agrad/rev/functions/trunc.hpp>
#include <stan/agrad/rev/functions/value_of.hpp>

#endif

==> pystan-2.5.0.0.tar.gz: pystan-2.5.0.0/pystan/stan/src/stan/agrad/rev/functions.hpp <==
#ifndef STAN__AGRAD__REV__FUNCTIONS_HPP
#define STAN__AGRAD__REV__FUNCTIONS_HPP

#include <stan/agrad/rev/functions/Phi.hpp>
#include <stan/agrad/rev/functions/Phi_approx.hpp>
#include <stan/agrad/rev/functions/abs.hpp>
#include <stan/agrad/rev/functions/acos.hpp>
#include <stan/agrad/rev/functions/acosh.hpp>
#include <stan/agrad/rev/functions/as_bool.hpp>
#include <stan/agrad/rev/functions/asin.hpp>
#include <stan/agrad/rev/functions/asinh.hpp>
#include <stan/agrad/rev/functions/atan.hpp>
#include <stan/agrad/rev/functions/atan2.hpp>
#include <stan/agrad/rev/functions/atanh.hpp>
#include <stan/agrad/rev/functions/bessel_first_kind.hpp>
#include <stan/agrad/rev/functions/bessel_second_kind.hpp>
#include <stan/agrad/rev/functions/binary_log_loss.hpp>
#include <stan/agrad/rev/functions/cbrt.hpp>
#include <stan/agrad/rev/functions/ceil.hpp>
#include <stan/agrad/rev/functions/cos.hpp>
#include <stan/agrad/rev/functions/cosh.hpp>
#include <stan/agrad/rev/functions/digamma.hpp>
#include <stan/agrad/rev/functions/erf.hpp>
#include <stan/agrad/rev/functions/erfc.hpp>
#include <stan/agrad/rev/functions/exp.hpp>
#include <stan/agrad/rev/functions/exp2.hpp>
#include <stan/agrad/rev/functions/expm1.hpp>
#include <stan/agrad/rev/functions/fabs.hpp>
#include <stan/agrad/rev/functions/falling_factorial.hpp>
#include <stan/agrad/rev/functions/fdim.hpp>
#include <stan/agrad/rev/functions/floor.hpp>
#include <stan/agrad/rev/functions/fma.hpp>
#include <stan/agrad/rev/functions/fmax.hpp>
#include <stan/agrad/rev/functions/fmin.hpp>
#include <stan/agrad/rev/functions/fmod.hpp>
#include <stan/agrad/rev/functions/gamma_p.hpp>
#include <stan/agrad/rev/functions/gamma_q.hpp>
#include <stan/agrad/rev/functions/hypot.hpp>
#include <stan/agrad/rev/functions/ibeta.hpp>
#include <stan/agrad/rev/functions/if_else.hpp>
#include <stan/agrad/rev/functions/inv.hpp>
#include <stan/agrad/rev/functions/inv_cloglog.hpp>
#include <stan/agrad/rev/functions/inv_logit.hpp>
#include <stan/agrad/rev/functions/inv_sqrt.hpp>
#include <stan/agrad/rev/functions/inv_square.hpp>
#include <stan/agrad/rev/functions/is_inf.hpp>
#include <stan/agrad/rev/functions/is_nan.hpp>
#include <stan/agrad/rev/functions/is_uninitialized.hpp>
#include <stan/agrad/rev/functions/lgamma.hpp>
#include <stan/agrad/rev/functions/lmgamma.hpp>
#include <stan/agrad/rev/functions/log.hpp>
#include <stan/agrad/rev/functions/log10.hpp>
#include <stan/agrad/rev/functions/log1m.hpp>
#include <stan/agrad/rev/functions/log1m_exp.hpp>
#include <stan/agrad/rev/functions/log1p.hpp>
#include <stan/agrad/rev/functions/log1p_exp.hpp>
#include <stan/agrad/rev/functions/log2.hpp>
#include <stan/agrad/rev/functions/log_diff_exp.hpp>
#include <stan/agrad/rev/functions/log_falling_factorial.hpp>
#include <stan/agrad/rev/functions/log_rising_factorial.hpp>
#include <stan/agrad/rev/functions/log_sum_exp.hpp>
#include <stan/agrad/rev/functions/modified_bessel_first_kind.hpp>
#include <stan/agrad/rev/functions/modified_bessel_second_kind.hpp>
#include <stan/agrad/rev/functions/multiply_log.hpp>
#include <stan/agrad/rev/functions/owens_t.hpp>
#include <stan/agrad/rev/functions/pow.hpp>
#include <stan/agrad/rev/functions/primitive_value.hpp>
#include <stan/agrad/rev/functions/rising_factorial.hpp>
#include <stan/agrad/rev/functions/round.hpp>
#include <stan/agrad/rev/functions/sin.hpp>
#include <stan/agrad/rev/functions/sinh.hpp>
#include <stan/agrad/rev/functions/sqrt.hpp>
#include <stan/agrad/rev/functions/square.hpp>
#include <stan/agrad/rev/functions/step.hpp>
#include <stan/agrad/rev/functions/tan.hpp>
#include <stan/agrad/rev/functions/tanh.hpp>
#include <stan/agrad/rev/functions/tgamma.hpp>
#include <stan/agrad/rev/functions/trunc.hpp>
#include <stan/agrad/rev/functions/value_of.hpp>

#endif
